"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LinkButton = exports.Button = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactRouterDom = require("react-router-dom");

var _withTheme = require("../../wrappers/with-theme");

var _excluded = ["onClick", "children", "confirmMessage", "type"],
    _excluded2 = ["children", "type", "showConfirm", "confirmMessage", "themeOptions"],
    _excluded3 = ["themeOptions", "className", "type", "children", "disabled"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var ConfirmButton = function ConfirmButton(_ref) {
  var onClick = _ref.onClick,
      children = _ref.children,
      confirmMessage = _ref.confirmMessage,
      type = _ref.type,
      props = _objectWithoutProperties(_ref, _excluded);

  var _React$useState = _react["default"].useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      canClick = _React$useState2[0],
      setCanClick = _React$useState2[1];

  var timeout = _react["default"].useRef(null);

  var confirm = _react["default"].useCallback(function (e) {
    e.preventDefault();
    setCanClick(true);
    timeout.current = setTimeout(setCanClick, 5000, false);
  }, [timeout]);

  var doOnClick = _react["default"].useCallback(function (e) {
    setCanClick(false);
    onClick && onClick(e);
  }, [onClick]);

  _react["default"].useEffect(function () {
    return function () {
      return clearTimeout(timeout.current);
    };
  }, [timeout]);

  return /*#__PURE__*/_react["default"].createElement("button", _extends({
    onClick: canClick ? type === "submit" ? null : doOnClick : confirm
  }, props, {
    type: canClick ? type : "button"
  }), /*#__PURE__*/_react["default"].createElement("div", {
    className: "relative w-full"
  }, !canClick ? null : /*#__PURE__*/_react["default"].createElement("div", {
    className: "absolute top-0 left-0 right-0 bottom-0 flex items-center overflow-hidden"
  }, /*#__PURE__*/_react["default"].createElement("div", null, confirmMessage)), /*#__PURE__*/_react["default"].createElement("div", {
    style: {
      color: canClick ? "transparent" : null
    }
  }, children)));
};

var Button = function Button(_ref2) {
  var children = _ref2.children,
      _ref2$type = _ref2.type,
      type = _ref2$type === void 0 ? "button" : _ref2$type,
      _ref2$showConfirm = _ref2.showConfirm,
      showConfirm = _ref2$showConfirm === void 0 ? false : _ref2$showConfirm,
      _ref2$confirmMessage = _ref2.confirmMessage,
      confirmMessage = _ref2$confirmMessage === void 0 ? "click to confirm" : _ref2$confirmMessage,
      _ref2$themeOptions = _ref2.themeOptions,
      themeOptions = _ref2$themeOptions === void 0 ? {} : _ref2$themeOptions,
      props = _objectWithoutProperties(_ref2, _excluded2);

  var fullTheme = (0, _withTheme.useTheme)();
  var theme = fullTheme['button'](themeOptions);

  if (showConfirm) {
    return /*#__PURE__*/_react["default"].createElement(ConfirmButton, _extends({
      type: type
    }, props, {
      confirmMessage: confirmMessage,
      className: "".concat(theme.button)
    }), children);
  }

  return /*#__PURE__*/_react["default"].createElement("button", _extends({
    type: type
  }, props, {
    className: "".concat(theme.button)
  }), children);
};

exports.Button = Button;

var LinkButton = function LinkButton(_ref3) {
  var _ref3$themeOptions = _ref3.themeOptions,
      themeOptions = _ref3$themeOptions === void 0 ? {} : _ref3$themeOptions,
      _ref3$className = _ref3.className,
      className = _ref3$className === void 0 ? "" : _ref3$className,
      type = _ref3.type,
      children = _ref3.children,
      disabled = _ref3.disabled,
      props = _objectWithoutProperties(_ref3, _excluded3);

  var fullTheme = (0, _withTheme.useTheme)();
  var buttonTheme = fullTheme['button'](themeOptions);
  return /*#__PURE__*/_react["default"].createElement(_reactRouterDom.Link, _extends({}, props, {
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    className: "".concat(buttonTheme, " ").concat(className)
  }), children);
};

exports.LinkButton = LinkButton;