"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _Top = _interopRequireDefault(require("./Top"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

//import { useTheme } from "../../wrappers";
var _default = {
  name: "Top Nav",
  themeVar: "topnav",
  description: "A responsive horizontal navigation component.",
  props: [{
    name: "menuItems",
    type: "Data",
    required: false,
    "default": [],
    description: ['An array of Objects which represent the menu items for the nav.' // 'Keys',
    // '',
    // 'name - The name value displayed for the item',
    // 'icon - optional - Icon class names',
    // 'to - optional - link url. will be active if is current page',
    // 'active - optional - set item to active style'
    ]
  }, {
    name: "leftMenu",
    type: "Component",
    required: false,
    "default": ''
  }, {
    name: "rightMenu",
    type: "Component",
    "default": ''
  }, {
    name: "mobileLocation",
    type: "String",
    "default": 'Top',
    required: false
  }],
  examples: [{
    Component: function Component(props) {
      return /*#__PURE__*/React.createElement("div", {
        className: "h-full w-full bg-gray-100"
      }, /*#__PURE__*/React.createElement(_Top["default"], props));
    },
    title: 'TopNav with icon, logo and login',
    props: [{
      name: "menuItems",
      "default": [{
        name: "Hello",
        icon: "os-icon os-icon-layout",
        active: true
      }, {
        name: "Applications",
        icon: "os-icon os-icon-package"
      }, {
        name: "Pages",
        icon: "os-icon os-icon-file-text"
      }, {
        name: "Emails",
        icon: "os-icon os-icon-mail"
      }, {
        name: "Users",
        icon: "os-icon os-icon-users"
      }, {
        name: "Forms",
        icon: "os-icon os-icon-edit-32"
      }, {
        name: "Tables",
        icon: "os-icon os-icon-grid"
      }]
    }, {
      name: "leftMenu",
      "default": /*#__PURE__*/React.createElement("div", {
        className: "flex items-center p-4 justify-center h-12"
      }, /*#__PURE__*/React.createElement("span", {
        className: "text-lg font-medium uppercase"
      }, "AVL Design"))
    }, {
      name: "rightMenu",
      "default": /*#__PURE__*/React.createElement("div", {
        className: "flex items-center md:w-32 justify-center h-12 w-full hover:bg-gray-400 hover:text-white"
      }, /*#__PURE__*/React.createElement("span", {
        className: "text-sm cursor-pointer"
      }, "Login"))
    }],
    code: "\n\t\t\timport {TopNav} from \"components/avl-components/src\"; \n\t\t\t\t\n\t\t\tconst MyTopBar = (props) => {\n\t\t\t\treturn (\n\t\t\t\t\t<div className=\"h-full w-full bg-gray-100\">\n\t\t\t\t\t\t\t\t<TopNav {...props} />\n\t\t\t\t\t\t</div>\n\t\t\t\t\t);\n\t\t\t};\t\t\t\n\t\t\t"
  }, {
    Component: function Component(props) {
      return /*#__PURE__*/React.createElement("div", {
        className: "h-full w-full bg-gray-100"
      }, /*#__PURE__*/React.createElement(_Top["default"], props));
    },
    title: 'TopNav without icon, logo and login',
    props: [{
      name: "menuItems",
      type: "data",
      "default": [{
        name: "Hello",
        active: true
      }, {
        name: "Applications"
      }, {
        name: "Pages"
      }, {
        name: "Emails"
      }, {
        name: "Users"
      }, {
        name: "Forms"
      }, {
        name: "Tables"
      }]
    }],
    code: "\n\t\t\timport {TopNav} from \"components/avl-components/src\"; \n\t\t\t\t\n\t\t\tconst MyTopBar = (props) => {\n\t\t\t\treturn (\n\t\t\t\t\t<div className=\"h-full w-full bg-gray-100\">\n\t\t\t\t\t\t\t\t<TopNav {...props} />\n\t\t\t\t\t\t</div>\n\t\t\t\t\t);\n\t\t\t};\t\t\t\n\t\t\t"
  }, {
    Component: function Component(props) {
      return /*#__PURE__*/React.createElement("div", {
        className: "h-full w-full bg-gray-100"
      }, /*#__PURE__*/React.createElement(_Top["default"], props));
    },
    title: 'TopNav with icon, logo',
    props: [{
      name: "menuItems",
      type: "data",
      "default": [{
        name: "Hello",
        icon: "os-icon os-icon-layout",
        active: true
      }, {
        name: "Applications",
        icon: "os-icon os-icon-package"
      }, {
        name: "Pages",
        icon: "os-icon os-icon-file-text"
      }, {
        name: "Emails",
        icon: "os-icon os-icon-mail"
      }, {
        name: "Users",
        icon: "os-icon os-icon-users"
      }, {
        name: "Forms",
        icon: "os-icon os-icon-edit-32"
      }, {
        name: "Tables",
        icon: "os-icon os-icon-grid"
      }]
    }, {
      name: "leftMenu",
      type: "Component",
      "default": /*#__PURE__*/React.createElement("div", {
        className: "flex items-center p-4 justify-center h-12"
      }, /*#__PURE__*/React.createElement("span", {
        className: "text-lg font-medium uppercase"
      }, "AVL Design"))
    }],
    theme: ["sidebarWrapper"],
    dependencies: [{
      name: "Nav Item",
      theme: ["navitemTop", "navitemTopActive", "menuIcon", "menuIcon"]
    }],
    code: "\n\t\t\timport {TopNav} from \"components/avl-components/src\"; \n\t\t\t\t\n\t\t\tconst MyTopBar = (props) => {\n\t\t\t\treturn (\n\t\t\t\t\t<div className=\"h-full w-full bg-gray-100\">\n\t\t\t\t\t\t\t\t<TopNav {...props} />\n\t\t\t\t\t\t</div>\n\t\t\t\t\t);\n\t\t\t};\t\t\t\n\t\t\t"
  }, {
    Component: function Component(props) {
      return /*#__PURE__*/React.createElement("div", {
        className: "h-full w-full bg-gray-100"
      }, /*#__PURE__*/React.createElement(_Top["default"], props));
    },
    title: 'TopNav with icon, login',
    props: [{
      name: "menuItems",
      type: "data",
      "default": [{
        name: "Hello",
        icon: "os-icon os-icon-layout",
        active: true
      }, {
        name: "Applications",
        icon: "os-icon os-icon-package"
      }, {
        name: "Pages",
        icon: "os-icon os-icon-file-text"
      }, {
        name: "Emails",
        icon: "os-icon os-icon-mail"
      }, {
        name: "Users",
        icon: "os-icon os-icon-users"
      }, {
        name: "Forms",
        icon: "os-icon os-icon-edit-32"
      }, {
        name: "Tables",
        icon: "os-icon os-icon-grid"
      }]
    }, {
      name: "rightMenu",
      type: "Component",
      "default": /*#__PURE__*/React.createElement("div", {
        className: "flex items-center md:w-32 justify-center h-12 w-full hover:bg-gray-400 hover:text-white"
      }, /*#__PURE__*/React.createElement("span", {
        className: "text-sm cursor-pointer"
      }, "Login"))
    }],
    theme: ["sidebarWrapper"],
    dependencies: [{
      name: "Nav Item",
      theme: ["navitemTop", "navitemTopActive", "menuIcon", "menuIcon"]
    }],
    code: "\n\t\t\timport {TopNav} from \"components/avl-components/src\"; \n\t\t\t\t\n\t\t\tconst MyTopBar = (props) => {\n\t\t\t\treturn (\n\t\t\t\t\t<div className=\"h-full w-full bg-gray-100\">\n\t\t\t\t\t\t\t\t<TopNav {...props} />\n\t\t\t\t\t\t</div>\n\t\t\t\t\t);\n\t\t\t};\t\t\t\n\t\t\t"
  }]
};
exports["default"] = _default;